@@ -57,6 +57,7 @@ describe 'keystone' do
       'signing_cert_subject'               => '<SERVICE DEFAULT>',
       'signing_key_size'                   => '<SERVICE DEFAULT>',
       'default_transport_url'              => '<SERVICE DEFAULT>',
+      'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_host'                        => '<SERVICE DEFAULT>',
       'rabbit_password'                    => '<SERVICE DEFAULT>',
       'rabbit_userid'                      => '<SERVICE DEFAULT>',
@@ -109,6 +110,7 @@ describe 'keystone' do
       'signing_cert_subject'               => '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com',
       'signing_key_size'                   => 2048,
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
+      'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
       'rabbit_host'                        => '127.0.0.1',
       'rabbit_password'                    => 'openstack',
       'rabbit_userid'                      => 'admin',
@@ -737,10 +739,12 @@ describe 'keystone' do
       default_params
     end
 
+    it { is_expected.to contain_keystone_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>') }
   end
 
   describe 'with RabbitMQ communication SSLed' do
@@ -754,13 +758,13 @@ describe 'keystone' do
       })
     end
 
-    it do
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('keystone_config').with(
+        :rabbit_use_ssl     => true,
+        :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+        :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+        :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+        :kombu_ssl_version  => 'TLSv1'
+    )}
   end
 
   describe 'with RabbitMQ communication not SSLed' do
@@ -774,13 +778,13 @@ describe 'keystone' do
       })
     end
 
-    it do
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('keystone_config').with(
+        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+        :kombu_ssl_version  => '<SERVICE DEFAULT>'
+    )}
   end
 
   describe 'when configuring max_token_size' do
@@ -794,10 +798,11 @@ describe 'keystone' do
   describe 'setting notification settings' do
     let :params do
       default_params.merge({
-        :notification_driver => ['keystone.openstack.common.notifier.rpc_notifier'],
-        :notification_topics => ['notifications'],
-        :notification_format => 'cadf',
-        :control_exchange    => 'keystone'
+        :notification_driver  => ['keystone.openstack.common.notifier.rpc_notifier'],
+        :notification_topics  => ['notifications'],
+        :notification_format  => 'cadf',
+        :control_exchange     => 'keystone',
+        :rpc_response_timeout => '120'
       })
     end
 
@@ -805,6 +810,7 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('oslo_messaging_notifications/topics').with_value('notifications') }
     it { is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('cadf') }
     it { is_expected.to contain_keystone_config('DEFAULT/control_exchange').with_value('keystone') }
+    it { is_expected.to contain_keystone_config('DEFAULT/rpc_response_timeout').with_value('120') }
   end
 
   describe 'setting kombu settings' do
@@ -1076,15 +1082,48 @@ describe 'keystone' do
     it { is_expected.to contain_file('/etc/keystone/fernet-keys/0').with(
       'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
       'owner'     => 'keystone',
-      'owner'     => 'keystone',
       'mode'      => '0600',
+      'replace'   => true,
       'subscribe' => 'Anchor[keystone::install::end]',
     )}
     it { is_expected.to contain_file('/etc/keystone/fernet-keys/1').with(
       'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
       'owner'     => 'keystone',
+      'mode'      => '0600',
+      'replace'   => true,
+      'subscribe' => 'Anchor[keystone::install::end]',
+    )}
+  end
+
+  describe 'when not replacing fernet_keys and setting fernet_keys parameter' do
+    let :params do
+      default_params.merge({
+        'enable_fernet_setup' => true,
+        'fernet_keys' => {
+          '/etc/keystone/fernet-keys/0' => {
+            'content' => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
+          },
+          '/etc/keystone/fernet-keys/1' => {
+            'content' => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
+          },
+        },
+        'fernet_replace_keys' => false,
+      })
+    end
+
+    it { is_expected.to_not contain_exec('keystone-manage fernet_setup') }
+    it { is_expected.to contain_file('/etc/keystone/fernet-keys/0').with(
+      'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
       'owner'     => 'keystone',
       'mode'      => '0600',
+      'replace'   => false,
+      'subscribe' => 'Anchor[keystone::install::end]',
+    )}
+    it { is_expected.to contain_file('/etc/keystone/fernet-keys/1').with(
+      'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
+      'owner'     => 'keystone',
+      'mode'      => '0600',
+      'replace'   => false,
       'subscribe' => 'Anchor[keystone::install::end]',
     )}
   end
